@@ -1,7 +1,5 @@
 #!/bin/bash
 
-MODE=${1:-double}
-
 cnfpath=`realpath ../conf/cluster_mgr.cnf`
 
 num=`ps -ef | grep ${cnfpath} | grep -v grep | grep -v vim | wc -l`
@@ -12,11 +10,7 @@ num=`ps -ef | grep ${cnfpath} | grep -v grep | grep -v vim | wc -l`
 
 ulimit -c unlimited
 if test "$USE_VALGRIND" = ""; then
-	if [ ${MODE} == "single" ]; then
-		./cluster_mgr ${cnfpath} ${MODE} >../log/std.log 2>&1 &
-	else
-		./cluster_mgr ${cnfpath} >../log/std.log 2>&1
-	fi
+	./cluster_mgr ${cnfpath} >../log/std.log 2>&1
 else
 	valgrind --leak-check=full --undef-value-errors=no ./cluster_mgr ${cnfpath} >../log/std.log 2>&1
 fi
